@@ -44,7 +44,24 @@ to group Notes together in intervals and chords."""
 	dynamics = {}
 
 	def __init__(self, name = 'C', octave = 4, dynamics = {}):
-		self.set_note(name, octave, dynamics)
+                if type(name) == str:
+        		self.set_note(name, octave, dynamics)
+
+                # Hardcopy Note object
+                elif hasattr(name, "name"):
+                        self.set_note(name.name, name.octave, name.dynamics)
+                        if hasattr(name, "channel"):
+                                self.channel = name.channel
+                        if hasattr(name, "velocity"):
+                                self.velocity = name.velocity
+
+
+                # Convert from integer
+                elif type(name) == int:
+                        self.from_int(name)
+
+                else:
+                        raise NoteFormatError, "Don't know what to do with name object: '%s'" % name
 
 	def set_note(self, name = 'C', octave = 4, dynamics = {}):
 		"""Sets the note to `name` in `octave` with `dynamics` if \
@@ -66,7 +83,7 @@ succeeded, raises an NoteFormatError otherwise."""
 				self.name = dash_index[0]
 				self.octave = int(dash_index[1])
 				self.dynamics = dynamics
-				return True
+				return self
 			else:
 				raise NoteFormatError,\
 					"The string '%s' is not a valid representation"\
@@ -149,6 +166,16 @@ Doesn't change the octave."""
 		self.octave = integer / 12
 		return self
 
+        def measure(self, other):
+                """Returns the number of semitones between this Note and the other.
+{{{
+>>> Note("C").measure(Note("D"))
+2
+>>> Note("D").measure(Note("C"))
+-2
+}}}"""
+                return int(other) - int(self)
+
 	def to_hertz(self, standard_pitch = 440):
 		"""Returns the Note in Hz. The `standard_pitch` argument can be used \
 to set the pitch of A-4, from which the rest is calculated."""
@@ -166,6 +193,60 @@ which the rest is calculated."""
 		self.name = notes.int_to_note(int(value) % 12)
 		self.octave = int(value / 12) + 4
 
+        def to_shorthand(self):
+                """Gives the traditional Helmhotz pitch notation.\
+{{{
+>>> Note("C-4").to_shorthand()
+"c'"
+>>> Note("C-3").to_shorthand()
+'c'
+>>> Note("C-2").to_shorthand()
+'C'
+>>> Note("C-1").to_shorthand()
+'C,'
+}}}"""
+                if self.octave < 3:
+                        res = self.name
+                else:
+                        res = str.lower(self.name)
+
+                o = self.octave - 3
+                while o < -1:
+                        res += ","
+                        o += 1
+                while o > 0:
+                        res += "'"
+                        o -= 1
+                return res
+
+        def from_shorthand(self, shorthand):
+                """Convert from traditional Helmhotz pitch notation.\
+{{{
+>>> Note().from_shorthand("C,,")
+'C-0'
+>>> Note().from_shorthand("C")
+'C-2'
+>>> Note().from_shorthand("c'")
+'C-4'
+}}}"""
+                name = ""
+                octave = 0
+                for x in shorthand:
+                        if x in ['a', 'b', 'c', 'd', 'e', 'f', 'g']:
+                                name = str.upper(x)
+                                octave = 3
+                        elif x in ['A', 'B', 'C', 'D', 'E', 'F', 'G']:
+                                name = x
+                                octave = 2
+                        elif x in ["#", "b"]:
+                                name += x
+                        elif x == ',':
+                                octave -= 1
+                        elif x == "'":
+                                octave += 1
+                return self.set_note(name, octave, {})
+
+
 	def __int__(self):
 		"""Returns the current octave multiplied by twelve and adds \
 notes.note_to_int to it. This means a C-0 returns 0, C-1 \
