@@ -34,6 +34,7 @@ Tracks can be stored together in [refMingusContainersComposition Compositions]""
 	bars = []
 	instrument = None
 	name = "Untitled" # Will be looked for when saving a MIDI file.
+        tuning = None # Used by tablature
 
 	def __init__(self, instrument = None):
 		self.bars = []
@@ -76,6 +77,21 @@ but the note turns out not to be within the range of the \
 
 		return self.bars[-1].place_notes(note, duration)
 	
+        def get_tuning(self):
+                """Returns a StringTuning object. If an instrument is set and has a \
+tuning it will be returned. Otherwise the track's one will be used."""
+                if self.instrument and self.instrument.tuning:
+                        return self.instrument.tuning
+                return self.tuning
+
+        def set_tuning(self, tuning):
+                """Sets the tuning attribute on both the Track and its instrument (when available). \
+Tuning should be a !StringTuning or derivative object."""
+                if self.instrument:
+                        self.instrument.tuning = tuning
+                self.tuning = tuning
+                return self
+
 	def transpose(self, interval, up = True):
 		"""Transposes all the notes in the track up or down the interval. Calls transpose() on every [refMingusContainersBar Bar]."""
 		for bar in self.bars:
